@@ -44,12 +44,12 @@ Extended Fields:
 - :class:`DummyField <lino.core.fields.DummyField>`
 - :func:`ForeignKey <lino.core.fields.ForeignKey>`
 
-Babel fields:
+Multilingual database content:
 
-- :class:`BabelNamed <lino.utils.babel.BabelNamed>`
-- :class:`BabelCharField <lino.utils.babel.BabelCharField>`
-- :class:`BabelTextField <lino.utils.babel.BabelTextField>`
-- :class:`LanguageField <lino.utils.babel.LanguageField>`
+- :class:`BabelNamed <north.babel.BabelNamed>`
+- :class:`BabelCharField <north.babel.BabelCharField>`
+- :class:`BabelTextField <fields.BabelTextField>`
+- :class:`LanguageField <north.babel.LanguageField>`
 
 Virtual Fields:
 
@@ -68,10 +68,14 @@ Layouts:
   
 Utilities:
 
+- :func:`obj2str <djangosite.dbutils.obj2str>`
+- :func:`obj2unicode <djangosite.dbutils.obj2unicode>`
+- :func:`range_filter <djangosite.dbutils.range_filter>`
+- :func:`full_model_name <djangosite.dbutils.full_model_name>`
 - :func:`fields_list <lino.core.fields.fields_list>`
-- :func:`resolve_field <lino.core.modeltools.resolve_field>`
-- :func:`resolve_model <lino.core.modeltools.resolve_model>`
-- :func:`resolve_app <lino.core.modeltools.resolve_app>` 
+- :func:`resolve_field <lino.core.dbutils.resolve_field>`
+- :func:`resolve_model <north.dbutils.resolve_model>`
+- :func:`resolve_app <lino.core.dbutils.resolve_app>` 
 - :func:`chooser <lino.utils.choosers.chooser>` 
 - :func:`add_user_group` 
 - :func:`update_field <lino.core.inject.update_field>` 
@@ -80,14 +84,16 @@ Utilities:
 
 Signals:
 
-- :attr:`pre_startup <lino.core.signals.pre_startup>`
+- :attr:`startup <djangosite.signals.startup>`
+- :attr:`pre_analyze <lino.core.signals.pre_analyze>`
+- :attr:`post_analyze <lino.core.signals.post_analyze>`
 - :attr:`pre_merge <lino.core.signals.pre_merge>`
 - :attr:`pre_ui_create <lino.core.signals.pre_ui_create>`
 - :attr:`ChangeWatcher <lino.core.signals.ChangeWatcher>`
 - :attr:`pre_ui_update <lino.core.signals.pre_ui_update>`
 - :attr:`pre_ui_delete <lino.core.signals.pre_ui_delete>`
-- :attr:`pre_analyze <lino.core.signals.pre_analyze>`
 - :attr:`receiver <django.dispatch.receiver>` : the standard Django receiver decorator
+- (and many more)
 
 Actions:
 
@@ -103,6 +109,7 @@ Miscellaneous:
 - :class:`ChoiceList <lino.core.choicelists.ChoiceList>`
 - :class:`Workflow <lino.core.workflows.Workflow>`
 
+- :class:`Genders <lino.core.choicelists.Genders>`
 
 - :class:`UserProfiles <lino.utils.auth.UserProfiles>`
 - :class:`UserGroups <lino.utils.auth.UserGroups>`
@@ -117,9 +124,14 @@ logger = logging.getLogger(__name__)
 
 from lino.core.tables import VirtualTable
 
-from lino.core.modeltools import resolve_model, resolve_app, resolve_field, get_field, UnresolvedModel
-from lino.core.modeltools import full_model_name
-from lino.core.modeltools import models_by_base
+from north.dbutils import resolve_model, UnresolvedModel
+
+from lino.core.dbutils import resolve_app, resolve_field, get_field
+from djangosite.dbutils import obj2str
+from djangosite.dbutils import obj2unicode
+from djangosite.dbutils import range_filter
+from djangosite.dbutils import full_model_name
+from djangosite.dbutils import models_by_base
 
 from lino.core.model import Model
 from lino.core.merge import MergeAction
@@ -137,7 +149,7 @@ from django.conf import settings
 from lino.core.dbtables import summary, summary_row
 
 from lino.core.frames import Frame
-from lino.core.dialogs import Dialog
+#~ from lino.core.dialogs import Dialog
 
 from lino.core.actions import action
 #~ from lino.core.actions import Action
@@ -152,6 +164,7 @@ from lino.core.actions import SubmitDetail, SubmitInsert
 #~ from lino.core.actions import Calendar
 
 from lino.core.choicelists import ChoiceList, Choice
+from lino.core.choicelists import Genders
 from lino.core.workflows import Workflow, ChangeStateAction
 #~ from lino.core.changes import ChangeStateAction
 from lino.core.actions import NotifyingAction
@@ -177,8 +190,10 @@ from lino.core.fields import VirtualField, virtualfield
 from lino.core.fields import RequestField, requestfield
 from lino.core.fields import Constant, constant
 from lino.core.fields import ForeignKey
+from lino.core.fields import BabelTextField
 
-from lino.utils.babel import BabelCharField, BabelTextField, BabelNamed, LanguageField
+from north.babel import BabelCharField, BabelNamed, LanguageField
+#~ from north.babel import BabelCharField, BabelTextField, BabelNamed, LanguageField
 #~ from lino.core.fields import MethodField
 
 from lino.utils.choosers import chooser
@@ -197,17 +212,25 @@ from lino.core.layouts import ParamsLayout
 
 
 from lino.core.signals import pre_ui_create, pre_ui_delete, pre_ui_update, ChangeWatcher
+from djangosite.signals import startup
+
 from lino.core.signals import pre_analyze
 from lino.core.signals import post_analyze
-
 from lino.core.signals import auto_create
 from lino.core.signals import pre_merge
 from lino.core.signals import pre_add_child
 from lino.core.signals import pre_remove_child
+from lino.core.signals import pre_ui_build
+from lino.core.signals import post_ui_build
+
+from django.db.models.signals import pre_save, post_save
+from django.db.backends.signals import connection_created
+
 
 from django.db.models.signals import class_prepared
 from django.db.models.fields import NOT_PROVIDED
 
+
 from django.dispatch import receiver
 #~ from lino.core import signals
 
@@ -237,12 +260,7 @@ def add_user_group(name,label):
         if g.text != label:
             g.text += " & " + unicode(label)
     
-def required(**kw):
-    #~ if not kw.has_key('auth'):
-        #~ kw.update(auth=True)
-    kw.setdefault('auth',True)
-    return kw
-    
+from lino.core.actors import get_default_required as required
     
 class PseudoRequest:
     def __init__(self,username):
@@ -251,8 +269,9 @@ class PseudoRequest:
         
     def get_user(self):
         if self._user is None:
-            if settings.LINO.user_model is not None:
-                self._user = settings.LINO.user_model.objects.get(username=self.username)
+            if settings.SITE.user_model is not None:
+                #~ print 20130222, self.username
+                self._user = settings.SITE.user_model.objects.get(username=self.username)
         return self._user
     user = property(get_user)
     
