@@ -39,7 +39,7 @@ from xml.dom import minidom
 
 from lino.utils import ucsv
 from lino.utils import dblogger as logger
-from north.babel import babel_values, DEFAULT_LANGUAGE
+from north.babel import babel_values
 from lino.modlib.countries.models import Country
 
 TABLE2 = """
@@ -115,7 +115,7 @@ def objects():
             yield Country(**kw)
         else:
             logger.debug("%r : no name for default babel language %s",
-                code,DEFAULT_LANGUAGE)
+                code,settings.SITE.DEFAULT_LANGUAGE)
             
     for ln in TABLE2.splitlines():
         ln = ln.strip()
