@@ -378,7 +378,7 @@ class Site(lino.Site):
     using the official 
     `eid-applet <http://code.google.com/p/eid-applet>`_.
     This option is experimental and doesn't yet work.
-    See :doc:`/blog/2012/1105`.
+    See `/blog/2012/1105`.
     """
     
     use_eid_jslib = False
@@ -402,7 +402,7 @@ class Site(lino.Site):
     
     use_filterRow = not use_gridfilters
     """
-    See :doc:`/blog/2011/0630`.
+    See `/blog/2011/0630`.
     This option was experimental and doesn't yet work (and maybe never will).
     """
     
@@ -416,7 +416,7 @@ class Site(lino.Site):
     """
     Whether to use TinyMCE instead of Ext.form.HtmlEditor. 
     See also :attr:`tinymce_root`.
-    See :doc:`/blog/2011/0523`.
+    See `/blog/2011/0523`.
     """
     
     use_bootstrap = True
@@ -451,7 +451,7 @@ class Site(lino.Site):
     """
     Whether to use VinylFox extensions for HtmlEditor. 
     This feature was experimental and doesn't yet work (and maybe never will).
-    See :doc:`/blog/2011/0523`.
+    See `/blog/2011/0523`.
     """
     
     webdav_root = None
@@ -535,9 +535,15 @@ class Site(lino.Site):
     
     _site_config = None
     
-    def init_nolocal(self,*args):
-        super(Site,self).init_nolocal(*args)
+    #~ def init_nolocal(self,*args):
+        #~ super(Site,self).init_nolocal(*args)
     
+        
+    def override_defaults(self,**kwargs):
+        """
+        """
+        super(Site,self).override_defaults(**kwargs)
+        
         installed_apps = tuple(self.get_installed_apps()) + ('lino','djangosite')
         self.update_settings(INSTALLED_APPS=installed_apps)
         
@@ -567,11 +573,10 @@ class Site(lino.Site):
         
         self.update_settings(
             ROOT_URLCONF = 'lino.ui.urls'
-          
         )
         self.update_settings(
-            MIDDLEWARE_CLASSES=tuple(self.get_middleware_classes()))
-                
+            MEDIA_URL = '/media/'
+        )
         self.update_settings(
             TEMPLATE_LOADERS=tuple([
                 'lino.core.web.Loader',
@@ -580,15 +585,6 @@ class Site(lino.Site):
                 #~ 'django.template.loaders.eggs.Loader',
                 ]))
            
-        #~ else:
-            #~ tl = [
-                #~ 'django.template.loaders.filesystem.Loader',
-                #~ 'django.template.loaders.app_directories.Loader',
-                #     'django.template.loaders.eggs.load_template_source',
-            #~ ]
-            #~ self.update_settings(TEMPLATE_LOADERS = tuple(tl))
-                
-                
         tcp = []
         if self.user_model == 'auth.User':
             self.update_settings(LOGIN_URL = '/accounts/login/')
@@ -604,6 +600,12 @@ class Site(lino.Site):
                 #~ 'django.contrib.messages.context_processors.messages',
         ]
         self.update_settings(TEMPLATE_CONTEXT_PROCESSORS = tuple(tcp))
+        
+        self.define_settings(
+            MIDDLEWARE_CLASSES=tuple(self.get_middleware_classes()))
+                
+        #~ print 20130313, self.django_settings['MIDDLEWARE_CLASSES']
+        
        
     def do_site_startup(self):
         super(Site,self).do_site_startup()
@@ -896,6 +898,8 @@ class Site(lino.Site):
         yield 'lino.modlib.about'
         #~ if self.admin_prefix:
             #~ yield 'lino.modlib.pages'
+        for a in self.user_apps:
+            yield a
         
     #~ def get_guest_greeting(self):
         #~ return xghtml.E.p("Please log in")
