@@ -694,7 +694,7 @@ class FieldElement(LayoutElement):
         
         # When used as editor of an EditorGridPanel, don't set the name attribute
         # because it is not needed for grids and might conflict with fields of a 
-        # surronding detail form. See ticket #38 (:doc:`/blog/2011/0408`).
+        # surronding detail form. See ticket #38 (`/blog/2011/0408`).
         # Also don't set a label then.
         if not isinstance(self.layout_handle.layout,layouts.ListLayout):
             kw.update(name=self.field.name)
@@ -1283,7 +1283,7 @@ class DisplayElement(FieldElement):
         
     def format_value(self,ar,v):
         from lino.utils.xmlgen.html import E
-        from lino.utils.rstgen import html2rst
+        from lino.utils.xmlgen.html import html2rst
         if etree.iselement(v): 
             return html2rst(v)
         return self.field._lino_atomizer.format_value(ar,v)
